# AIMMO Core Curation Service
The Aimmocore Curation SDK is a Python package that selects core data within a dataset through clustering techniques using metadata and embedding information of images.


## Requirements
- Python 3.8 or later

## Installation
```bash
pip install aimmocore
```